@@ -17,6 +17,7 @@ import pytest
 import subprocess
 import shutil
 import difflib
+from sys import stderr
 
 from plugin.utils import casing_utils
 
@@ -71,7 +72,10 @@ def run_protoc_gapic_plugin(output_dir, gapic_yaml, include_dirs, proto_files,
              '--plugin=protoc-gen-gapic=gapic_plugin.py']
     args += ['-I' + path for path in include_dirs]
     args += proto_files
-    subprocess.check_call(args)
+    try:
+        subprocess.check_call(args)
+    except subprocess.CalledProcessError as exc:
+        stderr.write("Status : FAIL, message %s" % exc.output)
 
 
 def clean_test_output():
@@ -93,8 +97,8 @@ def run_protoc():
                             'java')
 
 
-RESOURCE_NAMES_TO_GENERATE = ['shelf_book_name', 'shelf_name', 'archived_book_name',
-                              'deleted_book']
+RESOURCE_NAMES_TO_GENERATE = ['shelf_book_name', 'shelf_name',
+                              'archived_book_name', 'deleted_book']
 ONEOFS_TO_GENERATE = ['book_oneof']
 DONT_GENERATE = ['project_name']
 
@@ -124,7 +128,9 @@ class TestProtocGapicPlugin(object):
             casing_utils.get_parent_resource_name_class_name(oneof)
         parent_filename_fragment = \
             casing_utils.get_parent_resource_name_lower_underscore(oneof)
-        check_output(generated_parent, PROTOC_OUTPUT_DIR, 'java_' + parent_filename_fragment)
+        check_output(generated_parent,
+                     PROTOC_OUTPUT_DIR,
+                     'java_' + parent_filename_fragment)
 
     @pytest.mark.parametrize('oneof', ONEOFS_TO_GENERATE)
     def test_untyped_resource_name_generation(self, run_protoc, oneof):
@@ -132,7 +138,9 @@ class TestProtocGapicPlugin(object):
             casing_utils.get_untyped_resource_name_class_name(oneof)
         untyped_filename_fragment = \
             casing_utils.get_untyped_resource_name_lower_underscore(oneof)
-        check_output(generated_untyped, PROTOC_OUTPUT_DIR, 'java_' + untyped_filename_fragment)
+        check_output(generated_untyped,
+                     PROTOC_OUTPUT_DIR,
+                     'java_' + untyped_filename_fragment)
 
     @pytest.mark.parametrize('oneof', ONEOFS_TO_GENERATE)
     def test_resource_name_factory_generation(self, run_protoc, oneof):
@@ -140,4 +148,6 @@ class TestProtocGapicPlugin(object):
             casing_utils.get_resource_name_factory_class_name(oneof)
         parent_filename_fragment = \
             casing_utils.get_resource_name_factory_lower_underscore(oneof)
-        check_output(generated_parent, PROTOC_OUTPUT_DIR, 'java_' + parent_filename_fragment)
+        check_output(generated_parent,
+                     PROTOC_OUTPUT_DIR,
+                     'java_' + parent_filename_fragment)
